@@ -38,6 +38,7 @@
 #'   \item `correlation`: Pearson's correlation
 #'   \item `jaccard`: Jaccard coefficient
 #'   \item `ejaccard`: the real value version of `jaccard`
+#'   \item `fjaccard`: Fuzzy Jaccard coefficient
 #'   \item `dice`: Dice coefficient
 #'   \item `edice`: the real value version of `dice`
 #'   \item `hamann`: Hamann similarity
@@ -67,7 +68,7 @@
 #' mt <- Matrix::rsparsematrix(100, 100, 0.01)
 #' simil(mt, method = "cosine")[1:5, 1:5]
 simil <- function(x, y = NULL, margin = 1,
-                  method = c("cosine", "correlation", "jaccard", "ejaccard",
+                  method = c("cosine", "correlation", "jaccard", "ejaccard", "fjaccard",
                              "dice", "edice", "hamann", "faith", "simple matching"),
                   min_simil = NULL, rank = NULL, drop0 = FALSE, diag = FALSE,
                   use_nan = NULL, digits = 14) {
@@ -100,7 +101,7 @@ dist <- function(x, y = NULL, margin = 1,
 #' @import Rcpp
 #' @useDynLib proxyC
 proxy <- function(x, y = NULL, margin = 1,
-                  method = c("cosine", "correlation", "jaccard", "ejaccard",
+                  method = c("cosine", "correlation", "jaccard", "ejaccard", "fjaccard",
                              "dice", "edice", "hamann", "simple matching", "faith",
                              "euclidean", "chisquared", "kullback", "jeffreys", "jensen",
                              "manhattan", "maximum", "canberra", "minkowski", "hamming"),
@@ -198,7 +199,7 @@ proxy <- function(x, y = NULL, margin = 1,
                                      "hamann", "simple matching", "faith",
                                      "euclidean", "chisquared", "kullback", "manhattan",
                                      "maximum", "canberra", "minkowski", "hamming",
-                                     "jeffreys", "jensen")),
+                                     "jeffreys", "jensen", "fjaccard")),
             rank = rank,
             limit = min_proxy,
             weight = weight,
