@@ -28,6 +28,18 @@ double simil_ejaccard(colvec& col_i, colvec& col_j, double weight = 1) {
     return e / (accu(pow(col_i, weight)) + accu(pow(col_j, weight)) - e);
 }
 
+double simil_fjaccard(colvec& col_i, colvec& col_j) {
+    if (any(col_i < 0) || any(1.0 < col_i) ||
+        any(col_j < 0) || any(1.0 < col_j))
+        return std::numeric_limits<double>::quiet_NaN();
+    ucolvec l = (col_i <= col_j);
+    colvec min = (col_i % l) + (col_j % (1 - l));
+    colvec max = (col_i % (1 - l)) + (col_j % l);
+    // Rcout << "min\n" << min.t();
+    // Rcout << "max\n" << max.t();
+    return accu(min) / accu(max);
+}
+
 double simil_edice(colvec& col_i, colvec& col_j, double weight = 1) {
     double e = accu(col_i % col_j);
     if (e == 0) return 0;
@@ -218,6 +230,9 @@ struct pairWorker : public Worker {
                 case 17:
                     simil = dist_jensen(col_i, col_j, smooth);
                     break;
+                case 18:
+                    simil = simil_fjaccard(col_i, col_j);
+                    break;
                 }
                 //Rcout << "simil=" << simil << "\n";
                 simils.push_back(simil);
