@@ -47,6 +47,20 @@ test_that("test ejaccard similarity", {
     test_simil(mat_test[-1,], "ejaccard", margin = 2)
 })
 
+test_that("test fjaccard similarity", {
+    skip_if_not_installed("proxy")
+    # proxy::simil(method = "fjaccard") returns wrong scores
+    mat_prob <- rsparsematrix(100, 50, 0.5, rand.x = runif)
+
+    s1 <- as.matrix(simil(mat_prob, margin = 1, method = "fjaccard"))
+    s2 <- 1 - as.matrix(proxy::dist(as.matrix(mat_prob), method = "fjaccard", by_raw = TRUE))
+    expect_equal(as.numeric(s1), as.numeric(s2), tolerance = 0.001)
+
+    s3 <- as.matrix(simil(mat_prob, margin = 2, method = "fjaccard"))
+    s4 <- 1 - as.matrix(proxy::dist(as.matrix(mat_prob), method = "fjaccard", by_raw = FALSE))
+    expect_equal(as.numeric(s1), as.numeric(s2), tolerance = 0.001)
+})
+
 test_that("test dice similarity", {
     skip_if_not_installed("proxy")
     # proxy::simil(method = "dice") wrongly returns 1 for all0 or sd0 vector
@@ -244,5 +258,28 @@ test_that("simil returns zero or NaN correctly", {
         any(is.nan(as.numeric(proxyC::simil(mat, method = "faith", margin = 2, use_nan = TRUE))))
     )
 
+    mat2 <- Matrix::Matrix(matrix(c(-0.1, -0.1, -0.1,
+                                    0.1, 0.1, 0.1,
+                                    0.1, 0.5, 0.2,
+                                    0.2, 0.3, 0.4), byrow = TRUE, nrow = 4), sparse = TRUE)
+    mat3 <- Matrix::Matrix(matrix(c(1.1, 1.1, 1.1,
+                                    0.1, 0.1, 0.1,
+                                    0.1, 0.5, 0.2,
+                                    0.2, 0.3, 0.4), byrow = TRUE, nrow = 4), sparse = TRUE)
+
+    # fjaccard
+    expect_true(
+        any(is.nan(as.numeric(proxyC::simil(mat2, method = "fjaccard", margin = 1, use_nan = TRUE))))
+    )
+    expect_true(
+        any(is.nan(as.numeric(proxyC::simil(mat2, method = "fjaccard", margin = 2, use_nan = TRUE))))
+    )
+    expect_true(
+        any(is.nan(as.numeric(proxyC::simil(mat3, method = "fjaccard", margin = 1, use_nan = TRUE))))
+    )
+    expect_true(
+        any(is.nan(as.numeric(proxyC::simil(mat3, method = "fjaccard", margin = 2, use_nan = TRUE))))
+    )
+
 })
 
